@@ -1,9 +1,6 @@
-from cProfile import label
-from run import run_inference
+from .run import run_inference
 import torch
 import pyro.distributions as distr
-import pickle
-import os
 import pyro
 
 class Simulate():
